from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Int, Float

Ccmetagen_Py_V0_1_0 = CommandToolBuilder(tool="CCMetagen.py", base_command=["CCMetagen.py"], inputs=[ToolInput(tag="in_mode", input_type=File(optional=True), prefix="--mode", doc=InputDocumentation(doc="what do you want CCMetagen to do? Valid options are\n'visual', 'text' or 'both': text: parses kma, filters\nbased on quality and output a text file with taxonomic\ninformation and detailed mapping information visual:\nparses kma, filters based on quality and output a\nsimplified text file and a krona html file for\nvisualization both: outputs both text and visual file\nformats. Default = both")), ToolInput(tag="in_res_fp", input_type=File(optional=True), prefix="--res_fp", doc=InputDocumentation(doc="Path to the KMA result (.res file)")), ToolInput(tag="in_output_fp", input_type=File(optional=True), prefix="--output_fp", doc=InputDocumentation(doc="Path to the output file. Default = CCMetagen_out")), ToolInput(tag="in_reference_database", input_type=String(optional=True), prefix="--reference_database", doc=InputDocumentation(doc="Which reference database was used. Options: UNITE,\nRefSeq or nt. Default = nt")), ToolInput(tag="in_extended_output_file", input_type=File(optional=True), prefix="--extended_output_file", doc=InputDocumentation(doc="Produce an extended output file that includes the\npercentage of classified reads. Options: y or n. To\nuse this featire, you need to generate the mapstat\nfile when required unning KMA (use flag -ef), and use\nit as input in CCMetagen (flag --mapstat). Default = n")), ToolInput(tag="in_depth_unit", input_type=Int(optional=True), prefix="--depth_unit", doc=InputDocumentation(doc="Desired unit for Depth(abundance) measurements.\nDefault = kma (KMA default depth, which is the number\nof nucleotides overlapping each template, divided by\nthe lengh of the template). Alternatively, you can\nhave abundance calculated in Reads Per Million (RPM,\noption 'rpm'), in number of nucleotides overlaping the\ntemplate (option 'nc') or in number of fragments (i.e.\nPE reads, option 'fr'). If you use the 'nc', 'rpm' or\n'fr' options, remember to change the default --depth\nparameter accordingly. Valid options are nc, rpm, fr\nand kma")), ToolInput(tag="in_map_stat", input_type=Int(optional=True), prefix="--mapstat", doc=InputDocumentation(doc="Path to the mapstat file produced with KMA when using\nthe -ef flag (.mapstat). Required when calculating\nabundances in RPM or in number of fragments, or when\nproducing the extended_output_file")), ToolInput(tag="in_depth", input_type=Float(optional=True), prefix="--depth", doc=InputDocumentation(doc="minimum sequencing depth. Default = 0.2. The unit\ncorresponds to the one used with --depth_unit If you\nuse --depth_unit different from the default, change\nthis accordingly.")), ToolInput(tag="in_coverage", input_type=Int(optional=True), prefix="--coverage", doc=InputDocumentation(doc="Minimum coverage. Default = 20 (i.e. 20% of the\nreference sequence)")), ToolInput(tag="in_query_identity", input_type=Int(optional=True), prefix="--query_identity", doc=InputDocumentation(doc="Minimum query identity (Phylum level). Default = 50")), ToolInput(tag="in_p_value", input_type=Float(optional=True), prefix="--pvalue", doc=InputDocumentation(doc="Minimum p-value. Default = 0.05.")), ToolInput(tag="in_species_threshold", input_type=Float(optional=True), prefix="--species_threshold", doc=InputDocumentation(doc="Species-level similarity threshold. Default = 98.41")), ToolInput(tag="in_genus_threshold", input_type=Float(optional=True), prefix="--genus_threshold", doc=InputDocumentation(doc="Genus-level similarity threshold. Default = 96.31")), ToolInput(tag="in_family_threshold", input_type=Float(optional=True), prefix="--family_threshold", doc=InputDocumentation(doc="Family-level similarity threshold. Default = 88.51")), ToolInput(tag="in_order_threshold", input_type=Float(optional=True), prefix="--order_threshold", doc=InputDocumentation(doc="Order-level similarity threshold. Default = 81.21")), ToolInput(tag="in_class_threshold", input_type=Float(optional=True), prefix="--class_threshold", doc=InputDocumentation(doc="Class-level similarity threshold. Default = 80.91")), ToolInput(tag="in_phylum_threshold", input_type=Int(optional=True), prefix="--phylum_threshold", doc=InputDocumentation(doc="Phylum-level similarity threshold. Default = 0 - not\napplied")), ToolInput(tag="in_turn_off_sim_thresholds", input_type=String(optional=True), prefix="--turn_off_sim_thresholds", doc=InputDocumentation(doc="Turns simularity-based filtering off. Options = y or\nn. Default = n"))], outputs=[ToolOutput(tag="out_mode", output_type=File(optional=True), selector=InputSelector(input_to_select="in_mode", type_hint=File()), doc=OutputDocumentation(doc="what do you want CCMetagen to do? Valid options are\n'visual', 'text' or 'both': text: parses kma, filters\nbased on quality and output a text file with taxonomic\ninformation and detailed mapping information visual:\nparses kma, filters based on quality and output a\nsimplified text file and a krona html file for\nvisualization both: outputs both text and visual file\nformats. Default = both")), ToolOutput(tag="out_output_fp", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_fp", type_hint=File()), doc=OutputDocumentation(doc="Path to the output file. Default = CCMetagen_out")), ToolOutput(tag="out_extended_output_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_extended_output_file", type_hint=File()), doc=OutputDocumentation(doc="Produce an extended output file that includes the\npercentage of classified reads. Options: y or n. To\nuse this featire, you need to generate the mapstat\nfile when required unning KMA (use flag -ef), and use\nit as input in CCMetagen (flag --mapstat). Default = n"))], container="quay.io/biocontainers/ccmetagen:1.2.5--pyh3252c3a_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Ccmetagen_Py_V0_1_0().translate("wdl")

